@@ -22,7 +22,7 @@ SESSION_COOKIE_SECURE = False
 
 SECURE_HSTS_SECONDS = 0
 
-ALLOWED_HOSTS = ['localhost']
+ALLOWED_HOSTS = ['localhost', '127.0.0.1']
 
 INSTALLED_APPS += [
     'debug_toolbar',
