@@ -1,6 +1,7 @@
-from cms_qe_newsletter.models import Subscriber
 from django import forms
 
+from cms_qe_newsletter.models import Subscriber
+
 
 class SubscriberForm(forms.ModelForm):
     """
@@ -12,7 +13,7 @@ class SubscriberForm(forms.ModelForm):
         fields = ('email', 'first_name', 'last_name')
 
     def __init__(self, fullname_require, *args, **kwargs):
-        super(SubscriberForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self.fullname_require = fullname_require
         if fullname_require:
