@@ -17,9 +17,9 @@ def cms_qe_video_url_to_embed(url: str) -> str:
     """
 
     url = parse.urlparse(url)
-    if 'vimeo.com' in url.netloc:
+    if 'vimeo.com' in url.netloc:  # pylint: disable=R1705
         return parse.urlunparse((url.scheme, 'player.vimeo.com', '/video' + url.path, [], {}, ''))
-    elif 'youtube.com' in url.netloc or 'youtu.be' in url.netloc:
+    if 'youtube.com' in url.netloc or 'youtu.be' in url.netloc:
         video_id = parse.parse_qs(url.query)['v'][0]
         return parse.urlunparse((url.scheme, 'www.youtube.com', '/embed/' + video_id, [], {}, ''))
 
